/*!
 *****************************************************************************
 * @file:   ADuCM410_Setup.c
 * @brief:  setup for ADuCM410
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2013-2018 Analog Devices, Inc. All Rights Reserved.

This software is proprietary to Analog Devices, Inc. and its licensors.
By using this software you agree to the terms of the associated
Analog Devices Software License Agreement.
 ******************************************************************************/

#include "AdcLib.h"
#include "DacLib.h"
#include "ClkLib.h"

/*
   User can change following cofiguraion according to application
*/
CLK_SETUP_t gClkSetup = 
{
   //--------- configuration ---------
   .pllEn = 1,
   .rootClkMux = ENUM_CLOCK_CLKCON0_CLKMUX_SPLL,
   .analogClkMux = ENUM_CLOCK_CLKCON0_ANACLKMUX_HFOSC,

//-----------------Clock Divider -------------   
   .hclkDiv = ENUM_CLOCK_CLKCON1_CDHCLK_DIV1,
   .pclk0Div = ENUM_CLOCK_CLKCON1_CDPCLK0_DIV1,
   .pclk1Div = ENUM_CLOCK_CLKCON1_CDPCLK1_DIV8,
    
   .clockOff = 0x00000000,  //all clock on

   //---------Interrupt------------
   .pllIntEn = 0,    //0 - disalbe interrrupt related to PLL

   //-------TEST CLOCK -------
   .clkOutput = ENUM_CLOCK_CLKCON0_CLKOUT_ANA_CLK,
};

/*
   User can change following cofiguraion according to application
*/
ADC_SETUP_t gAdcSetup = 
{
   .adcPwrDown = 0,  //power up ADC
   .dmaEnForNonSeq = 0, //no DMA for non-sequence mode
   .dmaEnForSeq = 0, //no DMA for sequnce mode
   .pinMode = ENUM_ADC_ADCCON_PINMOD_PIN_EDGE,  //edge trigger if ADC conversion triggered by GPIO
   .timerTrigConv = 0,  //ADC conversion not triggered by timer event 
   .osr = ENUM_ADC_ADCCON_OSR_OSR_NS1, //no oversample
   .cnvFreqHighDiv = 320,   //conversion frequency = ADC clock/16
   .cnvFreqLowDiv = 320,     //conversion frequency = ADC clock/320
   .bypassPChanPreBuf = 0, //bypass P channel precharge buffer
   .bypassNChanPreBuf = 0, //bypass N channel precharge buffer
//------------ sequnce ---------
   .seqInterval = 255,  //run sequence once
   .seqEn = 0,       //enable sequence
//---------- Interrupt setup -------
   .CnvIntEn = 1, //enable ADC conversion interrupt
   .seqIntEn = 0, //disable sequence interrupt
   .refBufPwrDown = 0,  //reference buffer power up
};

//PGA working as TIA
PGA_SETUP_t gPgaSetup = 
{
   .vcm200BufPwrDown0 = 0,//200 mV VCM buffer0 enabled
   .vcm200BufPwrDown1 = 0,//200 mV VCM buffer1 enabled
	.bypassExtCap0 = 1,	// cap that used as LPF for PGA output
	.bypassExtCap1 = 1,	// cap that used as LPF for PGA output
   .pgaChxSetup[0] = {.pgaPwrDown=0,		//power PGA		
							.workAsTia = 0,	//work as PGA
							.tiaGain = ENUM_PGA_PGA0CON_TIAGAIN_RES5K,
							.tiaBias = ENUM_PGA_PGA0CON_TIAVDACSEL_VDAC8SEL,
							//configuration below can be ignored because working in TIA
							.pgaMode=ENUM_PGA_PGA0CON_PGAMODE_ACCOUPLE, 	//DC couple mode
							.pgaGain=ENUM_PGA_PGA0CON_PGAGAIN_GAIN4,		//PGA gain = 2
							.vcm1_25VBufPwrDown=0,		//power up 1.2V buffer
							.sinkDriveImprove = 0,	//normal mode, sink current ability is under 1mA
							.chopDis = 1,	
							},
	.pgaChxSetup[1] = {.pgaPwrDown=0,		//power PGA		
							.workAsTia = 0,	//work as PGA
							.tiaGain = ENUM_PGA_PGA0CON_TIAGAIN_RES5K,
							.tiaBias = ENUM_PGA_PGA0CON_TIAVDACSEL_VDAC8SEL,
							//configuration below can be ignored because working in TIA
							.pgaMode=ENUM_PGA_PGA0CON_PGAMODE_ACCOUPLE, 	//DC couple mode
							.pgaGain=ENUM_PGA_PGA0CON_PGAGAIN_GAIN2,		//PGA gain = 2
							.vcm1_25VBufPwrDown=0,		//power up 1.2V buffer
							.sinkDriveImprove = 0,	//normal mode, sink current ability is under 1mA
							.chopDis = 1,
							},
	.pgaChxSetup[2] = {.pgaPwrDown=0,		//power PGA		
							.workAsTia = 0,	//work as PGA
							.tiaGain = ENUM_PGA_PGA0CON_TIAGAIN_RES5K,
							.tiaBias = ENUM_PGA_PGA0CON_TIAVDACSEL_VDAC8SEL,
							//configuration below can be ignored because working in TIA
							.pgaMode=ENUM_PGA_PGA0CON_PGAMODE_ACCOUPLE, 	//DC couple mode
							.pgaGain=ENUM_PGA_PGA0CON_PGAGAIN_GAIN2,		//PGA gain = 2
							.vcm1_25VBufPwrDown=0,		//power up 1.2V buffer
							.sinkDriveImprove = 0,	//normal mode, sink current ability is under 1mA
							.chopDis = 1,
							},
	.pgaChxSetup[3] = {.pgaPwrDown=0,		//power PGA		
							.workAsTia = 0,	//work as PGA
							.tiaGain = ENUM_PGA_PGA0CON_TIAGAIN_RES5K,
							.tiaBias = ENUM_PGA_PGA0CON_TIAVDACSEL_VDAC8SEL,
							//configuration below can be ignored because working in TIA
							.pgaMode=ENUM_PGA_PGA0CON_PGAMODE_ACCOUPLE, 	//DC couple mode
							.pgaGain=ENUM_PGA_PGA0CON_PGAGAIN_GAIN2,		//PGA gain = 2
							.vcm1_25VBufPwrDown=0,		//power up 1.2V buffer
							.sinkDriveImprove = 0,	//normal mode, sink current ability is under 1mA
							.chopDis = 1,
							},
};





