/*!
 *****************************************************************************
 * @file:
 * @brief:
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2013-2018 Analog Devices, Inc. All Rights Reserved.

This software is proprietary to Analog Devices, Inc. and its licensors.
By using this software you agree to the terms of the associated
Analog Devices Software License Agreement.
 ******************************************************************************/

#include "ADuCM410.h"
#include "WdtLib.h"
#include "common.h"
#include "DioLib.h"
#include "AdcLib.h"
#include "DacLib.h"
#include "ClkLib.h"
#include "DacLib.h"

#ifdef REDIRECT_OUTPUT_TO_UART
   #define ADC_DATA_LENGTH 200
#else
   #define ADC_DATA_LENGTH 4
#endif

//Variables declaration
extern volatile uint32_t conversionDone;
extern volatile uint32_t dataCnt;
extern uint32_t AdcData[ADC_DATA_LENGTH];
extern const uint32_t pgaGain[];
	
// Function declaration
void delay(uint32_t t);
void AdcIntTest(void);

volatile uint32_t conversionDone = 0;
volatile uint32_t dataCnt = 0;
uint32_t AdcData[ADC_DATA_LENGTH];
const uint32_t pgaGain[]  = {1,2,4,6,8,10};

void AdcIntTest()
{
    float volt;
    int32_t code;
    AdcSetup(&gAdcSetup);
    AdcPinInt(CHAN_PGA0);//select internal ADC channel

    NVIC_EnableIRQ(ADC_IRQn);//enable interrupt
    AdcGo(ENUM_ADC_ADCCON_CONVTYPE_CONT);//ADC continous conversion
    while(conversionDone==0);   //wait for conversion finish

	DEBUG_MESSAGE("ADC raw data, voltage(mV), current(uA)");
    for(uint32_t i=0;i<ADC_DATA_LENGTH;i++)
    {
		if(AdcData[i]&BITM_ADC_ADCDAT_N__RDY)
		{
		    AdcData[i] = AdcData[i]>>BITP_ADC_ADCDAT_N__DAT;
          code = (int16_t)AdcData[i];
          volt = code/65536.0f*5000;
          DEBUG_MESSAGE("%d,%f",code,(double)volt);

		}
	 	else
		{
			DEBUG_MESSAGE("ERROR: interrupt without data ready");
		}

    } 
  
}

/*
   Tested with sinewave at PGA0P
   sinewave amplitude:200mV, offset:1.2V, frequency:5KHz
*/
int main (void)
{
   conversionDone = 0;
   dataCnt = 0;
   WdtGo(false);
   
   ClkSetup(&gClkSetup);
   DioCfgPin(pADI_GPIO2,PIN2,P2_2_CLKOUT);	//gpio MUX for clock out
   
    SystemInit();
   INIT();
   SafetyWait();
   
   
   PgaSetup(&gPgaSetup);
   delay(20000);
   AdcIntTest();
   
   while(1)
   {
      delay(10000);
      //WdtRefresh();
   }
}

void delay(uint32_t t)
{
   uint32_t i;
   for(i=0;i<t;i++);
}

//interrupt handler
void ADC_Int_Handler()
{
 	uint32_t data,sta;
	sta = pADI_ADC->ADCIRQSTAT;	//must read to clear status
   if(sta&BITM_ADC_ADCIRQSTAT_CNVIRQSTAT)	//conversion triggered interrupt
   {
      data = REG_ADC_PGA0_DAT16;	//interrupt is only cleared by reading data register
      if(!conversionDone)
      {
         AdcData[dataCnt++] = data;
      }
      if(dataCnt>=ADC_DATA_LENGTH)
      {
         conversionDone = 1;
         dataCnt = 0;
         AdcGo(ENUM_ADC_ADCCON_CONVTYPE_IDLE);   //stop conversion
      }
		
   }
   DEBUG_PIN1_TOGGLE(); 
}






